import { I18n, Metadata, dayjs } from '@zeedhi/core';
import { TekLibLocalStorage } from '../Helpers/TekLibLocalStorage';
import { AlertService, DialogService, Form } from '@zeedhi/common';

export class Util {
	public static doAsync(callBack: any, time: number) {
		return setTimeout(() => {
			callBack();
		}, time);
	}

	public static isNext(): boolean {
		return TekLibLocalStorage.getItem('IS_NEXT');
	}

	public static isProduct(): boolean {
		return window.parent === window;
	}

	public static changeDayjsLocale(locale: string) {
		if (locale === 'pt-BR') dayjs.locale('pt-br');
		else if (locale === 'es-CL') dayjs.locale('es');
		else dayjs.locale('en');
	}

	public static getUrlParameter(name: string) {
		const searchString = window.location.search.substring(1);
		const variableArray = searchString.split('&');
		const results = [];
		for (let i = 0; i < variableArray.length; i++) {
			const keyValuePair = variableArray[i].split('=');
			if (keyValuePair[0] === name) {
				results.push(decodeURIComponent(keyValuePair[1]).replace('+', ' '));
			}
		}
		if (results.length) {
			return results[0];
		}
		return '';
	}

	public static async getAsyncFormInstance(formName: string) {
		let formInstance: Form|null = null;
		while(!formInstance) {
			try {
				formInstance = Metadata.getInstance<Form>(formName);
			} catch (e) {
				await new Promise(f => setTimeout(f, 500));
			}
		}
		return formInstance;
	}

    public static alertMessage(message: string, type: string) {
        AlertService.show({
            name: 'basic-alert',
            text: I18n.translate(message),
            top: true,
            left: false,
            timeout: 10000,
            color: type,
            showDismiss: true
        });
    }

    public static showErrorMessage(error: any) {
        let msg = '';
        if (error.response && error.response.data && error.response.data.error) {
            msg = error.response.data.error;
        } else {
            msg = error;
        }
        if (!msg) {
            msg = 'UNEXPECTED_ERROR';
        }
        this.showDialogMessage('error', 'Erro', msg);
    }

    public static showDialogMessage(type : string, title : string, text : string) {
        title = I18n.translate(title);
        text = I18n.translate(text);
        DialogService.show({
            name: `${type}_dialog`,
            type,
            title,
            text,
        });
    }

    public static showSuccessMessage(message: string = '') {
        message = message || 'ALE_SUCCESS_PROCCESS';
        AlertService.show({
            name: 'basic-alert',
            text: I18n.translate(message),
            top: true,
            left: false,
            color: 'success',
            timeout: 5000,
            buttonsSlot: [
                {
                    name: 'undo-button',
                    component: 'ZdButton',
                    icon: true,
                    right: true,
                    iconName: 'close',
                    color: 'white',
                    events: {
                        click: () => { AlertService.hide(); },
                    },
                },
            ],
        });
    }

    public static validateForm(form : Form) {
        if (form.validate()) {
            return true;
        }
        this.showAlertRequiredFields();
        return false;
    }

    public static showAlertRequiredFields() {
        this.alertMessage('REQUIRED_FIELDS', 'error');
    }

    public static async getFileBase64(file: any) {
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.readAsDataURL(file);
            reader.onload = () => resolve(reader.result);
            reader.onerror = (error) => reject(error);
        });
    }
}
